==> haskell-ipynb-0.2-186-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ipynb.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ipynb
version:              0.2
visibility:           public
id:                   ipynb-0.2-GjSDKI1FiW06z1te5EuQWL
key:                  ipynb-0.2-GjSDKI1FiW06z1te5EuQWL
license:              BSD-3-Clause
copyright:            Copyright (C) 2019 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
synopsis:             Data structure for working with Jupyter notebooks (ipynb).
description:
    ipynb defines a data structure for representing Jupyter
    notebooks, along with ToJSON and FromJSON instances
    for conversion to and from JSON .ipynb files.

category:             Text
abi:                  8127adccb50e046f5200c2c33590bb73
exposed:              True
exposed-modules:      Data.Ipynb
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ipynb-0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ipynb-0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ipynb-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ipynb
hs-libraries:         HSipynb-0.2-GjSDKI1FiW06z1te5EuQWL
depends:
    aeson-2.1.2.1-LDBL5bcX1HC79scYyh3opi base-4.17.2.1
    base64-bytestring-1.2.1.0-4WGXcVCcj2fHlYYfmt97g1
    bytestring-0.11.5.3 containers-0.6.7 text-2.0.2
    unordered-containers-0.2.20-2kG5VEC3Gy42AwINT9WJ9w

haddock-interfaces:   /usr/share/doc/haskell-ipynb/html/ipynb.haddock
haddock-html:         /usr/share/doc/haskell-ipynb/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ipynb-0.2-187-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ipynb.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ipynb
version:              0.2
visibility:           public
id:                   ipynb-0.2-JI5lF7juS9B57NrhnPnLFj
key:                  ipynb-0.2-JI5lF7juS9B57NrhnPnLFj
license:              BSD-3-Clause
copyright:            Copyright (C) 2019 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
synopsis:             Data structure for working with Jupyter notebooks (ipynb).
description:
    ipynb defines a data structure for representing Jupyter
    notebooks, along with ToJSON and FromJSON instances
    for conversion to and from JSON .ipynb files.

category:             Text
abi:                  b27538c8e3f7910b92e3e52c137d0455
exposed:              True
exposed-modules:      Data.Ipynb
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ipynb-0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ipynb-0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ipynb-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ipynb
hs-libraries:         HSipynb-0.2-JI5lF7juS9B57NrhnPnLFj
depends:
    aeson-2.1.2.1-17AWhWkbfJE926UMi0wPlA base-4.17.2.1
    base64-bytestring-1.2.1.0-4WGXcVCcj2fHlYYfmt97g1
    bytestring-0.11.5.3 containers-0.6.7 text-2.0.2
    unordered-containers-0.2.20-2kG5VEC3Gy42AwINT9WJ9w

haddock-interfaces:   /usr/share/doc/haskell-ipynb/html/ipynb.haddock
haddock-html:         /usr/share/doc/haskell-ipynb/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
